        integer Ioprim       ! primary container.  code subcode ...etc
        integer Inpxyz, Inpdir, Inperg, Inpsubcode, Inptime, 
     *  Inp1ry, Inpmul
	integer IoCont, Ir1,  Nevent
	real*8  JobTime, BaseTime
        character*8 pdatE0, ptimE0, Ddate, DeadLine
        character*256 EpicsFile, SepicsFile, ConfigFile
        character*256  PrimaryFile

       parameter(  Ioprim=15 )
c             sepics common
         common /ZsepManegc/ EpicsFile, SepicsFile, ConfigFile,
     *  PrimaryFile,
     *  ptimE0,  pdatE0, Ddate, DeadLine

         common /ZsepManeg/ BaseTime,
     *   IoCont, JobTime,
     *   Ir1(2), Nevent,
     *   Inpxyz, Inpdir, Inperg, Inpsubcode, Inptime, Inp1ry,
     *   Inpmul

c
c IoCont: fortran dev # for cont dataset.
c  BaseTime: base time for completing 1 gev event.
c        to is used to judge time needed for an event
c pdatE0: to keep first exEcution date
c ptimE0: //                      time
c



 



       

